# Changelog

- * 7a85b32 - 2019-01-12: Pre-Release v9.4.56.dev3 
- * a26f1df - 2019-01-12: Building of DEV docker images now implemented 
- * baf04a1 - 2019-01-12: Fixed issue with connecting to RARBG torrent provider 
- * 831f077 - 2019-01-13: Update .gitlab-ci.yml 
- * 7c6290c - 2019-01-13: Update .gitlab-ci.yml 
- * bf51f72 - 2019-01-13: Update .gitlab-ci.yml 
- * 560357a - 2019-01-12: Update .gitlab-ci.yml 
- * 2543e7c - 2019-01-12: Update .gitlab-ci.yml 
- * 6e96928 - 2019-01-12: Refactored processed marker code 
- * 60c219a - 2019-01-12: Update Dockerfile 
- * 74f25eb - 2019-01-12: Update Dockerfile 
- * 5fcae91 - 2019-01-12: Update Dockerfile 
- * c27cdf7 - 2019-01-12: Update Dockerfile 
- * 68a9176 - 2019-01-12: Update .gitlab-ci.yml 
- * 3f76554 - 2019-01-12: Update .gitlab-ci.yml 
- * d326930 - 2019-01-12: Update .gitlab-ci.yml 


